@@ -8,7 +8,7 @@ use base "Net::Autoconfig::Device";
 use Log::Log4perl qw(:levels);
 use Expect;
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 
 #################################################################################
 ## Constants and Global Variables
@@ -33,7 +33,7 @@ use constant SHORT_TIMEOUT  =>  5;
 # Yay!
 ####################
 my $expect_ssh_key_cmd   = '[
-                            -re => "continue connecting \(yes\/no\)",
+                            -re => "continue connecting",
                             sub
                             {
                                 $session->clear_accum();
@@ -59,7 +59,8 @@ my $expect_password_cmd = '[
                             }
                         ]';
 my $expect_hp_continue_cmd = '[
-                            -re => "any key to continue",
+                            #-re => "any key to continue",
+                            -re => "continue",
                             sub
                             {
                                 $session->clear_accum();
@@ -213,7 +214,7 @@ sub connect {
     if ($self->access_method =~ /^ssh$/)
     {
         # Force using ssh version 1 due to old firmware problems.
-        $spawn_cmd = join(" ", $self->access_cmd, "-1 -l", $self->username, $self->hostname);
+        $spawn_cmd = join(" ", $self->access_cmd, "-l", $self->username, $self->hostname);
     }
     else
     {
